# Examples

Here are some example outputs from test cases in the [CalculiX test directory](https://github.com/Dhondtguido/CalculiX/tree/master/test):

- **anipla2**:
  ![anipla2](https://github.com/user-attachments/assets/32bea8bd-d705-401c-8503-14b69111adda)

- **beamf**:
  ![beamf](https://github.com/user-attachments/assets/45ce4a86-e391-46d5-911a-3ede6a9c90e7)

- **beamp**:
  ![beamp](https://github.com/user-attachments/assets/b36ef2fb-6555-4cc4-bc29-191e32d3591d)

These `.vtu` files were generated using `frd2vtu` and visualized with `frd2vtu_plot`.
